@@ -20,7 +20,7 @@
 #include <KPluginFactory>
 #include <KPluginMetaData>
 #include <KSharedConfig>
-#include <kdeclarative/kdeclarative.h>
+#include <kwidgetsaddons_version.h>
 
 #include <NetworkManagerQt/ActiveConnection>
 #include <NetworkManagerQt/Connection>
@@ -58,10 +58,6 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
     auto mainWidget = new QWidget(this);
     m_ui->setupUi(mainWidget);
 
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(m_ui->connectionView->engine());
-    kdeclarative.setupEngine(m_ui->connectionView->engine());
-
     KLocalizedContext *l10nContext = new KLocalizedContext(m_ui->connectionView->engine());
     l10nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     m_ui->connectionView->engine()->rootContext()->setContextObject(l10nContext);
@@ -282,7 +278,6 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
     if (type == NetworkManager::ConnectionSettings::Vpn && vpnType == "imported") {
         importVpn();
     } else if (type == NetworkManager::ConnectionSettings::Gsm) { // launch the mobile broadband wizard, both gsm/cdma
-#if WITH_MODEMMANAGER_SUPPORT
         QPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, this);
         wizard->setAttribute(Qt::WA_DeleteOnClose);
         connect(wizard.data(), &MobileConnectionWizard::accepted, [wizard, this]() {
@@ -316,7 +311,6 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
         });
         wizard->setModal(true);
         wizard->show();
-#endif
     } else {
         NetworkManager::ConnectionSettings::Ptr connectionSettings;
         connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(type));
@@ -418,13 +412,14 @@ void KCMNetworkmanagement::onRequestExportConnection(const QString &connectionPa
 
         const QString url =
             QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation) + QDir::separator() + vpnPlugin->suggestedFileName(connSettings);
-        const QString filename = QFileDialog::getSaveFileName(this, i18n("Export VPN Connection"), url, vpnPlugin->supportedFileExtensions());
+        const QString filename =
+            QFileDialog::getSaveFileName(this, i18n("Export VPN Connection"), url, vpnPlugin->supportedFileExtensions().join(QLatin1Char(' ')));
         if (!filename.isEmpty()) {
-            if (!vpnPlugin->exportConnectionSettings(connSettings, filename)) {
-                // TODO display failure
-                qCWarning(PLASMA_NM_KCM_LOG) << "Failed to export VPN connection";
-            } else {
+            if (auto result = vpnPlugin->exportConnectionSettings(connSettings, filename)) {
                 // TODO display success
+            } else {
+                // TODO display failure
+                qCWarning(PLASMA_NM_KCM_LOG) << "Failed to export VPN connection" << result.errorMessage();
             }
         }
     } else {
@@ -437,14 +432,23 @@ void KCMNetworkmanagement::onRequestToChangeConnection(const QString &connection
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(m_currentConnectionPath);
 
     if (connection) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KMessageBox::questionTwoActions(this,
+#else
         if (KMessageBox::questionYesNo(this,
-                                       i18n("Do you want to save changes made to the connection '%1'?", connection->name()),
-                                       i18nc("@title:window", "Save Changes"),
-                                       KStandardGuiItem::save(),
-                                       KStandardGuiItem::discard(),
-                                       QString(),
-                                       KMessageBox::Notify)
+
+#endif
+                                            i18n("Do you want to save changes made to the connection '%1'?", connection->name()),
+                                            i18nc("@title:window", "Save Changes"),
+                                            KStandardGuiItem::save(),
+                                            KStandardGuiItem::discard(),
+                                            QString(),
+                                            KMessageBox::Notify)
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             == KMessageBox::Yes) {
+#endif
             save();
         }
     }
@@ -514,71 +518,65 @@ void KCMNetworkmanagement::importVpn()
 {
     // get the list of supported extensions
     const QVector<KPluginMetaData> services = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"));
-    QString extensions;
+    QStringList extensions;
     for (const KPluginMetaData &service : services) {
         const auto result = KPluginFactory::instantiatePlugin<VpnUiPlugin>(service);
         if (result) {
-            extensions += result.plugin->supportedFileExtensions() % QStringLiteral(" ");
+            extensions += result.plugin->supportedFileExtensions();
             delete result.plugin;
         }
     }
 
-    const QString &filename = QFileDialog::getOpenFileName(this, i18n("Import VPN Connection"), QDir::homePath(), extensions.simplified());
+    const QString &filename =
+        QFileDialog::getOpenFileName(this, i18n("Import VPN Connection"), QDir::homePath(), i18n("VPN connections (%1)", extensions.join(QLatin1Char(' '))));
 
-    if (!filename.isEmpty()) {
-        const QVector<KPluginMetaData> services = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"));
+    if (filename.isEmpty()) {
+        return;
+    }
 
-        QFileInfo fi(filename);
-        const QString ext = QStringLiteral("*.") % fi.suffix();
-        qCDebug(PLASMA_NM_KCM_LOG) << "Importing VPN connection " << filename << "extension:" << ext;
+    QFileInfo fi(filename);
+    const QString ext = QStringLiteral("*.") % fi.suffix();
+    qCDebug(PLASMA_NM_KCM_LOG) << "Importing VPN connection " << filename << "extension:" << ext;
 
-        // Handle WireGuard separately because it is different than all the other VPNs
-        if (WireGuardInterfaceWidget::supportedFileExtensions().contains(ext)) {
-            NMVariantMapMap connection = WireGuardInterfaceWidget::importConnectionSettings(filename);
-            NetworkManager::ConnectionSettings connectionSettings;
-            connectionSettings.fromMap(connection);
-            connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
+    // Handle WireGuard separately because it is different than all the other VPNs
+    if (WireGuardInterfaceWidget::supportedFileExtensions().contains(ext)) {
+        NMVariantMapMap connection = WireGuardInterfaceWidget::importConnectionSettings(filename);
+        NetworkManager::ConnectionSettings connectionSettings;
+        connectionSettings.fromMap(connection);
+        connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
 
-            // qCDebug(PLASMA_NM_KCM_LOG) << "Converted connection:" << connectionSettings;
+        // qCDebug(PLASMA_NM_KCM_LOG) << "Converted connection:" << connectionSettings;
 
-            m_handler->addConnection(connectionSettings.toMap());
-            // qCDebug(PLASMA_NM_KCM_LOG) << "Adding imported connection under id:" << conId;
+        m_handler->addConnection(connectionSettings.toMap());
+        // qCDebug(PLASMA_NM_KCM_LOG) << "Adding imported connection under id:" << conId;
 
-            if (!connection.isEmpty()) {
-                return; // get out if the import produced at least some output
-            }
+        if (!connection.isEmpty()) {
+            return; // get out if the import produced at least some output
         }
-        for (const KPluginMetaData &service : services) {
-            const auto result = KPluginFactory::instantiatePlugin<VpnUiPlugin>(service);
+    }
+    for (const KPluginMetaData &service : services) {
+        const auto result = KPluginFactory::instantiatePlugin<VpnUiPlugin>(service);
+
+        if (!result) {
+            continue;
+        }
+
+        std::unique_ptr<VpnUiPlugin> vpnPlugin(result.plugin);
+
+        if (vpnPlugin->supportedFileExtensions().contains(ext)) {
+            qCDebug(PLASMA_NM_KCM_LOG) << "Found VPN plugin" << service.name() << ", type:" << service.value("X-NetworkManager-Services");
+
+            VpnUiPlugin::ImportResult result = vpnPlugin->importConnectionSettings(filename);
 
             if (!result) {
-                continue;
+                qWarning(PLASMA_NM_KCM_LOG) << "Failed to import" << filename << result.errorMessage();
+                break;
             }
 
-            std::unique_ptr<VpnUiPlugin> vpnPlugin(result.plugin);
+            m_handler->addConnection(result.connection());
 
-            if (vpnPlugin->supportedFileExtensions().contains(ext)) {
-                qCDebug(PLASMA_NM_KCM_LOG) << "Found VPN plugin" << service.name() << ", type:" << service.value("X-NetworkManager-Services");
-
-                NMVariantMapMap connection = vpnPlugin->importConnectionSettings(filename);
-
-                // qCDebug(PLASMA_NM_KCM_LOG) << "Raw connection:" << connection;
-
-                NetworkManager::ConnectionSettings connectionSettings;
-                connectionSettings.fromMap(connection);
-                connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
-
-                // qCDebug(PLASMA_NM_KCM_LOG) << "Converted connection:" << connectionSettings;
-
-                m_handler->addConnection(connectionSettings.toMap());
-                // qCDebug(PLASMA_NM_KCM_LOG) << "Adding imported connection under id:" << conId;
-
-                if (connection.isEmpty()) { // the "positive" part will arrive with connectionAdded
-                    // TODO display success
-                } else {
-                    break; // stop iterating over the plugins if the import produced at least some output
-                }
-            }
+            // qCDebug(PLASMA_NM_KCM_LOG) << "Adding imported connection under id:" << conId;
+            break;
         }
     }
 }
